td.folderOpen16{
background-image:url('/style/simple/16/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:22px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderClosed16{
background-image:url('/style/simple/16/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:22px;
height:22px;
font-size:14px;
vertical-align:top;
}
td.minusNode16{
background-image:url('/style/simple/16/html-menu-treeview/minusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
}
td.lastMinusNode16{
background-image:url('/style/simple/16/html-menu-treeview/lastMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
}
td.plusNode16{
background-image:url('/style/simple/16/html-menu-treeview/plusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
}
td.lastPlusNode16{
background-image:url('/style/simple/16/html-menu-treeview/lastPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:22px;
}
td.node16{
background-image:url('/style/simple/16/html-menu-treeview/node.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:14px;
height:22px;

}
td.submenuDeco16{
background-image:url('/style/simple/16/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
}
td.lastNode16{
background-image:url('/style/simple/16/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:14px;
height:22px;

}
a.treeviewLink16{
font-size:14px;
color:black;
cursor:pointer;
height:22px;
}
a.treeviewLink16:hover{
font-size:14px;
height:22px;
color:blue;
cursor:pointer;
}
td.clasicMinusNode16{
background-image:url('/style/simple/16/html-menu-treeview/clasicMinusNode.gif');
cursor:pointer;
}
td.clasicLastMinusNode16{
background-image:url('/style/simple/16/html-menu-treeview/clasicLastMinusNode.gif');
cursor:pointer;
}
td.clasicPlusNode16{
background-image:url('/style/simple/16/html-menu-treeview/clasicPlusNode.gif');
cursor:pointer;
}
td.clasicLastPlusNode16{
background-image:url('/style/simple/16/html-menu-treeview/clasicLastPlusNode.gif');
cursor:pointer;
}

td.columnsFolder16{
vertical-align:top;
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
}
td.columnsNode16{
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
}
td.columnsLastNode16{
color:black;
font-size:14px;
font-family:verdana, sans-serif;
height:22px;
white-space: nowrap;
}
td.caption16{
color:black;
height:24px;
font-size:16px;
white-space: nowrap;
font-family:verdana, sans-serif;
}
td.columnsFolderBorder16{
vertical-align:top;
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsNodeBorder16{
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsLastNodeBorder16{
color:black;
font-size:14px;
font-family:verdana, sans-serif;
height:22px;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.captionBorder16{
color:black;
height:24px;
font-size:16px;
white-space: nowrap;
font-family:verdana, sans-serif;
vertical-align:top;
border-bottom:1px;
border-bottom-style:dashed;
}
