td.clasicMinusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/clasicMinusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
}
td.clasicLastMinusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/clasicLastMinusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
height:22px;
}
td.clasicPlusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/clasicPlusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
height:22px;
}
td.clasicLastPlusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/clasicLastPlusNode.gif');
cursor:pointer;
height:22px;
background-repeat:no-repeat;
}
td.folder16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderYellow16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderYellow.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderYellowClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderYellowClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderViolet16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderViolet.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderVioletClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderVioletClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderOrange16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderOrange.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderOrangeClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderOrangeClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderRed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderRed.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderRedClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderRedClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderGray16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderGray.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderGrayClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderGrayClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderGreen16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderGreen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderGreenClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderGreenClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderMan16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderMan.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderManClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderManClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderHtml16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderHtml.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderHtmlClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderHtmlClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderFavorite16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderFavorite.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderFavoriteClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderFavoriteClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderText16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderText.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderTextClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderTextClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderLocked16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderLocked.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderLockedClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderLockedClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderCrystal16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderCrystal.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderCrystalClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderCrystalClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderVideo16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderVideo.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderVideoClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderVideoClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderPrint16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderPrint.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderPrintClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderPrintClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderSentMail16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderSentMail.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderSentMailClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderSentMailClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderImage16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderImage.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderImageClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderImageClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderSound16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderSound.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderSoundClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderSoundClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderImportant16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderImportant.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderImportantClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderImportantClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.folderTar16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderTar.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
vertical-align:top;
}
td.folderTarClosed16{
background-image:url('/style/Crystal/16/html-menu-treeview/folderTarClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:22px;
color:black;
vertical-align:top;
}
td.minusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/minusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
height:22px;
}
td.lastMinusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/lastMinusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
height:22px;
}
td.plusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/plusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
height:22px;
}
td.lastPlusNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/lastPlusNode.gif');
cursor:pointer;
height:22px;
background-repeat:no-repeat;
}
td.node16{
background-image:url('/style/Crystal/16/html-menu-treeview/node.gif');
cursor:pointer;
font-size:14px;
height:22px;
background-repeat:repeat-y;
vertical-align:top;
text-align:left;
}
td.submenuDeco16{
background-image:url('/style/Crystal/16/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
}
td.lastNode16{
background-image:url('/style/Crystal/16/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:14px;
height:22px;
}
a.treeviewLink16{
font-size:14px;
color:black;
cursor:pointer;
height:22px;
font-family:verdana,sans-serif;
}
a.treeviewLink16:hover{
font-size:14px;
height:22px;
color:blue;
cursor:pointer;
font-family:verdana,sans-serif;
vertical-align:top;
}
td.columnsFolder16{
vertical-align:top;
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;

}
td.columnsNode16{
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;

}
td.columnsLastNode16{
color:black;
font-size:14px;
font-family:verdana, sans-serif;
height:22px;
white-space: nowrap;
vertical-align:top;
}
td.caption16{
color:black;
height:24px;
font-size:16px;
white-space: nowrap;
font-family:verdana, sans-serif;
vertical-align:top;
}
td.columnsFolderBorder16{
vertical-align:top;
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsNodeBorder16{
color:black;
font-size:14px;
height:22px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsLastNodeBorder16{
color:black;
font-size:14px;
font-family:verdana, sans-serif;
height:22px;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.captionBorder16{
color:black;
height:24px;
font-size:16px;
white-space: nowrap;
font-family:verdana, sans-serif;
vertical-align:top;
border-bottom:1px;
border-bottom-style:dashed;
}
