td.clasicMinusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/clasicMinusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
}
td.clasicLastMinusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/clasicLastMinusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
height:88px;
}
td.clasicPlusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/clasicPlusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
height:88px;
}
td.clasicLastPlusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/clasicLastPlusNode.gif');
cursor:pointer;
height:88px;
background-repeat:no-repeat;
}
td.folderOpen64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderYellow64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderYellow.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderYellowClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderYellowClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderViolet64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderViolet.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderVioletClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderVioletClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderOrange64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderOrange.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderOrangeClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderOrangeClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderRed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderRed.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderRedClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderRedClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderGray64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderGray.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderGrayClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderGrayClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderGreen64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderGreen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderGreenClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderGreenClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderMan64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderMan.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderManClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderManClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderHtml64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderHtml.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderHtmlClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderHtmlClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderFavorite64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderFavorite.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderFavoriteClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderFavoriteClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderText64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderText.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderTextClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderTextClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderLocked64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderLocked.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderLockedClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderLockedClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderCrystal64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderCrystal.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderCrystalClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderCrystalClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderVideo64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderVideo.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderVideoClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderVideoClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderPrint64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderPrint.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderPrintClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderPrintClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderImage64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderImage.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderImageClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderImageClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderSound64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderSound.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderSoundClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderSoundClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderImportant64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderImportant.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderImportantClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderImportantClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.folderTar64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderTar.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderTarClosed64{
background-image:url('/style/Crystal/64/html-menu-treeview/folderTarClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:68px;
font-size:64px;
height:88px;
color:black;
vertical-align:top;
}
td.minusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/minusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
}
td.lastMinusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/lastMinusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
}
td.plusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/plusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
}
td.lastPlusNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/lastPlusNode.gif');
cursor:pointer;
height:88px;
background-repeat:no-repeat;
}
td.node64{
background-image:url('/style/Crystal/64/html-menu-treeview/node.gif');
cursor:pointer;
font-size:64px;
height:88px;
background-repeat:repeat-y;
text-align:left;
}
td.submenuDeco64{
background-image:url('/style/Crystal/64/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
}
td.lastNode64{
background-image:url('/style/Crystal/64/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:64px;
height:88px;
}
a.treeviewLink64{
font-size:64px;
color:black;
cursor:pointer;
height:88px;
font-family:verdana,sans-serif;
}
a.treeviewLink64:hover{
font-size:64px;
height:88px;
color:blue;
cursor:pointer;
font-family:verdana,sans-serif;
}
td.columnsFolder64{
font-size:64px;
height:88px;
font-family:verdana, sans-serif;
white-space: nowrap
}
td.columnsNode64{
font-size:64px;
height:88px;
font-family:verdana, sans-serif;
white-space: nowrap
}
td.columnsLastNode64{
font-size:64px;
height:88px;
font-family:verdana, sans-serif;
white-space: nowrap
}
td.columnsFolder64{
font-size:64px;
height:88px;
font-family:verdana, sans-serif;
white-space: nowrap;
}
td.columnsFolderBorder64{
vertical-align:top;
color:black;
font-size:64px;
height:88px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsNodeBorder64{
color:black;
font-size:64px;
height:88px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsLastNodeBorder64{
color:black;
font-size:64px;
height:88px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.captionBorder64{
color:black;
font-size:64px;
height:88px;
white-space: nowrap;
font-family:verdana, sans-serif;
vertical-align:top;
border-bottom:1px;
border-bottom-style:dashed;
}