td.clasicMinusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/clasicMinusNode.gif');
cursor:pointer;
}
td.clasicLastMinusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/clasicLastMinusNode.gif');
cursor:pointer;
}
td.clasicPlusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/clasicPlusNode.gif');
cursor:pointer;
}
td.clasicLastPlusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/clasicLastPlusNode.gif');
cursor:pointer;
}
td.folderYellow22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderYellow.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderYellowClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderYellowClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}

td.folderViolet22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderViolet.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderVioletClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderVioletClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}

td.folderGray22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderGray.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderGrayClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderGrayClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}

td.folder22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}
td.folderOrange22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderOrange.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderOrangeClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderOrangeClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}
td.folderRed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderRed.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderRedClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderRedClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}
td.folderGreen22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderGreen.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderGreenClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderGreenClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}
td.folderPrint22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderPrint.gif');
background-repeat:no-repeat;
color:black;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
vertical-align:top;
}
td.folderPrintClosed22{
background-image:url('/style/Crystal/22/html-menu-treeview/folderPrintClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:25px;
font-size:21px;
height:30px;
color:black;
vertical-align:top;
}
td.minusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/minusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
}
td.lastMinusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/lastMinusNode.gif');
cursor:pointer;
background-repeat:no-repeat;
}
td.plusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/plusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
}
td.lastPlusNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/lastPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:30px;
}
td.node22{
background-image:url('/style/Crystal/22/html-menu-treeview/node.gif');
cursor:pointer;
font-size:21px;
height:30px;
}
td.submenuDeco22{
background-image:url('/style/Crystal/22/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
}
td.lastNode22{
background-image:url('/style/Crystal/22/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:21px;
height:30px;
}
a.treeviewLink22{
font-size:21px;
color:black;
cursor:pointer;
height:30px;
}
a.treeviewLink22:hover{
font-size:21px;
height:22px;
color:blue;
cursor:pointer;
}
td.columnsNode22{
font-size:21px;
height:30px;
white-space: nowrap;
font-family:verdana, sans-serif;
}
td.columnsLastNode22{
font-size:21px;
height:30px;
white-space: nowrap;
font-family:verdana, sans-serif;
}
td.columnsFolder22{
font-size:21px;
height:30px;
vertical-align:top;
font-family:verdana, sans-serif;
white-space: nowrap;
}
td.caption22{
height:30px;
font-size:21px;
font-family:verdana, sans-serif;
white-space: nowrap;
}
td.columnsFolderBorder22{
vertical-align:top;
color:black;
height:30px;
font-size:21px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsNodeBorder22{
color:black;
height:30px;
font-size:21px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.columnsLastNodeBorder22{
color:black;
height:30px;
font-size:21px;
font-family:verdana, sans-serif;
white-space: nowrap;
vertical-align:top;
border-left:1px;
border-left-style:dashed;
}
td.captionBorder22{
color:black;
height:30px;
font-size:21px;
white-space: nowrap;
font-family:verdana, sans-serif;
vertical-align:top;
border-bottom:1px;
border-bottom-style:dashed;
}

